@@ -4,7 +4,7 @@ import random
 from datetime import date, datetime, time, timedelta
 from typing import List, Union, Optional, Dict, Tuple
 
-from .elements_base import Action, Value, MultiChoiceInput
+from .elements_base import _Action, Value, MultiChoiceInput
 from .elements_base import Element, MediaElement, InputElement, \
                            ActionChoiceInput, ChoiceInput, ChoiceInput1D, \
                            OtherChoiceInput, TextInput, \
@@ -19,7 +19,7 @@ from .util import RADIO_SYMBOLS, CHECKBOX_SYMBOLS, add_indent, elem_separator, r
 from .validators import GridValidator
 
 
-__all__ = ['Element', 'Action', 'CallbackRetVal', 'Value',
+__all__ = ['Element', '_Action', 'CallbackRetVal', 'Value',
            'Page', 'Comment', 'Image', 'Video',
            'Short', 'Paragraph', 'Radio', 'Dropdown', 'Checkboxes', 'Scale',
            'RadioGrid', 'CheckboxGrid',
@@ -53,7 +53,14 @@ CallbackRetVal = Union[ElemValue, Value]
 
 
 class Page(Element):
-    class Index(Element.Index):
+    """A Page element.
+
+    Attributes:
+        index: Index of the page.
+        elements: A list of elements contained within the page.
+    """
+
+    class _Index(Element._Index):
         ACTION = 5
 
     SUBMIT: Optional[Page] = None
@@ -61,20 +68,20 @@ class Page(Element):
     @classmethod
     def first(cls):
         return cls(
-            id_=Action.FIRST,
+            id_=_Action.FIRST,
             name=None,
             description=None,
             type_=Element.Type.PAGE,
-            prev_action=Action.NEXT,  # ignored
+            prev_action=_Action.NEXT,  # ignored
         ).with_index(0)
 
     @classmethod
     def _parse(cls, elem):
         res = super()._parse(elem)
-        res['prev_action'] = Action.NEXT
-        if len(elem) > cls.Index.ACTION:
+        res['prev_action'] = _Action.NEXT
+        if len(elem) > cls._Index.ACTION:
             # FIRST / NEXT / SUBMIT / page id
-            res['prev_action'] = elem[cls.Index.ACTION]
+            res['prev_action'] = elem[cls._Index.ACTION]
         return res
 
     def __init__(self, *, prev_action, **kwargs):
@@ -93,6 +100,8 @@ class Page(Element):
         self.elements.append(elem)
 
     def next_page(self):
+        """The next pge, based on user's choices."""
+
         if self._next_page is None:
             return None
 
@@ -103,6 +112,8 @@ class Page(Element):
         return next_page
 
     def to_str(self, indent=0, include_answer=False):
+        """See base class."""
+
         title = f'Page {self.index + 1}:'
         if self.name:
             title = f'{title} {self.name}'
@@ -126,6 +137,8 @@ class Page(Element):
         )
 
     def payload(self) -> Dict[str, List[str]]:
+        """Returns a combined payload of all elements from this page."""
+
         payload = {}
         for elem in self.elements:
             if isinstance(elem, InputElement):
@@ -133,32 +146,34 @@ class Page(Element):
         return payload
 
     def draft(self) -> List[Tuple]:
+        """Returns a combined draftResponse."""
+
         result = []
         for elem in self.elements:
             if isinstance(elem, InputElement):
                 result += elem.draft()
         return result
 
-    def resolve_actions(self, next_page: Page, mapping):
+    def _resolve_actions(self, next_page: Page, mapping):
         for elem in self.elements:
             if isinstance(elem, ActionChoiceInput):
-                elem.resolve_actions(next_page, mapping)
+                elem._resolve_actions(next_page, mapping)
 
         if next_page is None:
             return
-        if next_page._prev_action == Action.SUBMIT:
+        if next_page._prev_action == _Action.SUBMIT:
             self._has_default_next_page = False
             return
 
-        if next_page._prev_action == Action.NEXT:
+        if next_page._prev_action == _Action.NEXT:
             self._next_page = next_page
         else:
             self._next_page = mapping[next_page._prev_action]
             self._has_default_next_page = False
 
 
-Page.SUBMIT = Page(id_=Action.SUBMIT, name=None, description=None,
-                   type_=Element.Type.PAGE, prev_action=None).with_index(Action.SUBMIT)
+Page.SUBMIT = Page(id_=_Action.SUBMIT, name=None, description=None,
+                   type_=Element.Type.PAGE, prev_action=None).with_index(_Action.SUBMIT)
 
 
 class Comment(Element):
@@ -173,7 +188,7 @@ class Image(MediaElement):
 
 
 class Video(MediaElement):
-    class Index(MediaElement.Index):
+    class _Index(MediaElement._Index):
         VIDEO = 6
         LINK = 3
 
@@ -181,7 +196,7 @@ class Video(MediaElement):
     def _parse(cls, elem):
         res = super()._parse(elem)
         res.update({
-            'link': elem[cls.Index.VIDEO][cls.Index.LINK]
+            'link': elem[cls._Index.VIDEO][cls._Index.LINK]
         })
         return res
 
@@ -198,6 +213,8 @@ class Video(MediaElement):
 
 
 class Short(TextInput):
+    """A single-line text input."""
+
     def _validate_entry(self, index):
         super()._validate_entry(index)
         if not self._value:
@@ -208,16 +225,18 @@ class Short(TextInput):
 
 
 class Paragraph(TextInput):
+    """A multi-line text input."""
+
     pass
 
 
 class Radio(ActionChoiceInput, OtherChoiceInput):
     _choice_symbols = RADIO_SYMBOLS
 
-    def resolve_actions(self, next_page, mapping):
+    def _resolve_actions(self, next_page, mapping):
         if isinstance(self.other_option, ActionOption):
-            self.other_option.resolve_action(next_page, mapping)
-        super().resolve_actions(next_page, mapping)
+            self.other_option._resolve_action(next_page, mapping)
+        super()._resolve_actions(next_page, mapping)
 
 
 class Dropdown(ActionChoiceInput):
@@ -228,17 +247,37 @@ class Checkboxes(OtherChoiceInput, MultiChoiceInput):
     _choice_symbols = CHECKBOX_SYMBOLS
 
     def set_value(self, value: Union[CheckboxesValue, EmptyValue]):
+        """Sets the value for this element.
+
+        Accepts a choice value (a string or an Option),
+        a list of choice values or an empty value.
+
+        Args:
+            value: The value for this element.
+
+        Raises:
+            gforms.errors.ElementTypeError:
+                The argument's type is not accepted by this element.
+        """
+
         return self._set_choices([self._to_choice_list(value)])
 
 
 class Scale(ChoiceInput1D):
-    class Index(ChoiceInput.Index):
+    """A liner scale.
+
+    Attributes:
+        low: The label for the lowest value (may be empty).
+        high: The label for the highest value (may be empty).
+    """
+
+    class _Index(ChoiceInput._Index):
         LABELS = 3
 
     @classmethod
     def _parse(cls, elem):
         res = super()._parse(elem)
-        low, high = cls._get_entry(elem)[cls.Index.LABELS]
+        low, high = cls._get_entry(elem)[cls._Index.LABELS]
         res.update({
             'low': low,
             'high': high,
@@ -251,6 +290,18 @@ class Scale(ChoiceInput1D):
         self.high = high
 
     def set_value(self, value: Union[ScaleValue, EmptyValue]):
+        """Sets the value for this element.
+
+        Accepts a string, an Option, an int or an empty value.
+
+        Args:
+            value: The value for this element.
+
+        Raises:
+            gforms.errors.ElementTypeError:
+                The argument's type is not accepted by this element.
+        """
+
         if isinstance(value, int):
             value = str(value)
         return self._set_choices([self._to_choice_list(value)])
@@ -277,6 +328,22 @@ class RadioGrid(Grid):
     _cell_symbols = RADIO_SYMBOLS
 
     def set_value(self, value: Union[RadioGridValue, EmptyValue]):
+        """Sets the value for this element.
+
+        Accepts an empty value or a list of choice values,
+        each of which is a string, an Option or an empty value
+
+        Args:
+            value: The value for this element.
+
+        Raises:
+            gforms.errors.ElementTypeError:
+                The argument's type is not accepted by this element.
+            gforms.errors.ElementValueError:
+                The argument is a list,
+                but its length does not match the number of rows.
+        """
+
         # NOTE Maybe it's better to allow list of lists with lengths <= 1
         # grid.set_value([[val1], [], [val3], ...])
         # instead of grid.set_value([val1, Value.EMPTY, val3, ...])
@@ -287,11 +354,39 @@ class CheckboxGrid(Grid, MultiChoiceInput):
     _cell_symbols = CHECKBOX_SYMBOLS
 
     def set_value(self, value: Union[CheckboxGridValue, EmptyValue]):
+        """Sets the value for this element.
+
+        Accepts the same values as RadioGrid, but also
+        allows each list element to be a list of strings or Option objects.
+
+        Args:
+            value: The value for this element.
+
+        Raises:
+            gforms.errors.ElementTypeError:
+                The argument's type is not accepted by this element.
+            gforms.errors.ElementValueError:
+                The argument is a list,
+                but its length does not match the number of rows.
+        """
+
         self._set_grid_values(value)
 
 
 class Time(TimeElement):
     def set_value(self, value: Union[TimeValue, EmptyValue]):
+        """Sets the value for this element.
+
+        Accepts a datetime.time or an empty value.
+
+        Args:
+            value: The value for this element.
+
+        Raises:
+            gforms.errors.ElementTypeError:
+                The argument's type is not accepted by this element.
+        """
+
         if value is Value.EMPTY:
             return self._set_time(None, None, None)
         if isinstance(value, time):
@@ -310,6 +405,18 @@ class Duration(TimeElement):
         self._timedelta = None
 
     def set_value(self, value: Union[DurationValue, EmptyValue]):
+        """Sets the value for this element.
+
+        Accepts a datetime.timedelta or an empty value.
+
+        Args:
+            value: The value for this element.
+
+        Raises:
+            gforms.errors.ElementTypeError:
+                The argument's type is not accepted by this element.
+        """
+
         if value is Value.EMPTY:
             self._set_time(None, None, None)
             self._timedelta = None
@@ -322,6 +429,8 @@ class Duration(TimeElement):
             raise ElementTypeError(self, value)
 
     def validate(self):
+        """See base class."""
+
         super().validate()
         if self._timedelta is None:
             return
@@ -340,6 +449,18 @@ class Duration(TimeElement):
 
 class Date(DateElement):
     def set_value(self, value: Union[DateValue, EmptyValue]):
+        """Sets the value for this element.
+
+        Accepts a datetime.date or an empty value.
+
+        Args:
+            value: The value for this element.
+
+        Raises:
+            gforms.errors.ElementTypeError:
+                The argument's type is not accepted by this element.
+        """
+
         if value is Value.EMPTY:
             self._date = None
         elif isinstance(value, date):
@@ -354,6 +475,18 @@ class DateTime(DateElement):
         self._time = None
 
     def set_value(self, value: Union[DateTimeValue, EmptyValue]):
+        """Sets the value for this element.
+
+        Accepts a datetime.datetime or an empty value.
+
+        Args:
+            value: The value for this element.
+
+        Raises:
+            gforms.errors.ElementTypeError:
+                The argument's type is not accepted by this element.
+        """
+
         if value is Value.EMPTY:
             date_ = time_ = None
         elif isinstance(value, datetime):
@@ -364,6 +497,8 @@ class DateTime(DateElement):
         self._time = time_
 
     def payload(self) -> Dict[str, List[str]]:
+        """See base class."""
+
         if self._date is None:
             return {}
         payload = super().payload()
@@ -374,6 +509,8 @@ class DateTime(DateElement):
         return payload
 
     def draft(self) -> List[Tuple]:
+        """See base class."""
+
         if self._date is None:
             return []
         result = super().draft()
@@ -382,6 +519,8 @@ class DateTime(DateElement):
         return result
 
     def validate(self):
+        """See base class."""
+
         super().validate()
         if self.required and self._time is None:
             raise RequiredElement(self)
@@ -432,6 +571,8 @@ def _val_grid_choices(elem):
 
 
 def default_callback(elem: InputElement, page_index, elem_index) -> Union[ElemValue, EmptyValue]:
+    """The default callback implementation for Form.fill."""
+
     if isinstance(elem, Scale) or isinstance(elem, Dropdown):
         return random.choice(elem.options)
     if isinstance(elem, Radio):
@@ -475,7 +616,9 @@ _element_mapping = {getattr(Element.Type, el_type.__name__.upper()): el_type for
 
 
 def parse(elem):
-    el_type = Element.Type(elem[Element.Index.TYPE])
+    """Creates an Element of the right type from its JSON representation."""
+
+    el_type = Element.Type(elem[Element._Index.TYPE])
     if el_type is Element.Type.GRID:
         cls = CheckboxGrid if Grid.parse_multichoice(elem) else RadioGrid
     elif el_type is Element.Type.DATE:
